@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::GenericInterface::Operation::Ticket::TicketUpdate;
@@ -1243,7 +1243,7 @@ sub _CheckAttachment {
     }
 
     # check attachment item internally
-    for my $Needed (qw(Content ContentType Filename)) {
+    for my $Needed (qw(Content ContentType)) {
         if ( !$Attachment->{$Needed} ) {
             return {
                 ErrorCode    => 'TicketUpdate.MissingParameter',
@@ -1252,6 +1252,14 @@ sub _CheckAttachment {
         }
     }
 
+    # Check Filename separately because it can be '0'. See bug#14761.
+    if ( !IsStringWithData( $Attachment->{Filename} ) ) {
+        return {
+            ErrorCode    => 'TicketCreate.MissingParameter',
+            ErrorMessage => "TicketCreate: Attachment->Filename  parameter is missing!",
+        };
+    }
+
     # check Article->ContentType
     if ( $Attachment->{ContentType} ) {
 
@@ -2048,8 +2056,32 @@ sub _TicketUpdate {
             $From = $UserData{UserFullname};
         }
 
-        # set Article To
-        my $To = '';
+        # Set Article To, Cc, Bcc.
+        my ( $To, $Cc, $Bcc );
+        if ( $Article->{To} ) {
+            $To = $Article->{To};
+        }
+        if ( $Article->{Cc} ) {
+            $Cc = $Article->{Cc};
+        }
+        if ( $Article->{Bcc} ) {
+            $Bcc = $Article->{Bcc};
+        }
+
+        # Fallback for To
+        if ( !$To && $Article->{CommunicationChannel} eq 'Email' ) {
+
+            # Use data from customer user (if customer user is in database).
+            if ( IsHashRefWithData( \%CustomerUserData ) ) {
+                $To = '"' . $CustomerUserData{UserFullname} . '"'
+                    . ' <' . $CustomerUserData{UserEmail} . '>';
+            }
+
+            # Otherwise use customer user as sent from the request (it should be an email).
+            else {
+                $To = $Ticket->{CustomerUser} // $TicketData{CustomerUserID};
+            }
+        }
 
         if ( !$Article->{CommunicationChannel} ) {
 
@@ -2082,6 +2114,8 @@ sub _TicketUpdate {
             IsVisibleForCustomer => $Article->{IsVisibleForCustomer},
             From                 => $From,
             To                   => $To,
+            Cc                   => $Cc,
+            Bcc                  => $Bcc,
             Subject              => $Article->{Subject},
             Body                 => $Article->{Body},
             MimeType             => $Article->{MimeType} || '',
@@ -2295,8 +2329,8 @@ sub _TicketUpdate {
 
             next ATTACHMENT if !IsHashRefWithData( \%Attachment );
 
-            # convert content to base64
-            $Attachment{Content} = MIME::Base64::encode_base64( $Attachment{Content} );
+            # convert content to base64, but prevent 76 chars brake, see bug#14500.
+            $Attachment{Content} = MIME::Base64::encode_base64( $Attachment{Content}, '' );
             push @Attachments, {%Attachment};
         }
 
@@ -2326,10 +2360,10 @@ sub _TicketUpdate {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
