@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -753,8 +753,8 @@ sub _ShowScreen {
                     Invoker      => $Param{Invoker},
                     Event        => $Event->{Event},
                     Type         => $EventType // '-',
-                    Asynchronous => $Event->{Asynchronous} ? 'Yes' : 'No',
-                    Condition    => IsHashRefWithData( $Event->{Condition} ) ? 'Yes' : 'No',
+                    Asynchronous => $Event->{Asynchronous} ? Translatable('Yes') : Translatable('No'),
+                    Condition    => IsHashRefWithData( $Event->{Condition} ) ? Translatable('Yes') : Translatable('No'),
                 },
             );
         }
