@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -257,12 +257,12 @@ sub Run {
         my $Priorities = $Self->_GetPriorities(
             %GetParam,
             CustomerUserID => $CustomerUser || '',
-            TicketID => $Self->{TicketID},
+            TicketID       => $Self->{TicketID},
         );
         my $NextStates = $Self->_GetNextStates(
             %GetParam,
             CustomerUserID => $CustomerUser || '',
-            TicketID => $Self->{TicketID},
+            TicketID       => $Self->{TicketID},
         );
 
         # update Dynamic Fields Possible Values via AJAX
@@ -583,8 +583,7 @@ sub Run {
             );
         }
 
-        my $From = "$Self->{UserFullname} <$Self->{UserEmail}>";
-
+        my $From     = "\"$Self->{UserFullname}\" <$Self->{UserEmail}>";
         my $MimeType = 'text/plain';
         if ( $LayoutObject->{BrowserRichText} ) {
             $MimeType = 'text/html';
@@ -649,7 +648,7 @@ sub Run {
             },
             HistoryType      => $Config->{HistoryType},
             HistoryComment   => $Config->{HistoryComment} || '%%',
-            AutoResponseType => 'auto follow up',
+            AutoResponseType => ( $ConfigObject->Get('AutoResponseForWebTickets') ) ? 'auto follow up' : '',
         );
         if ( !$ArticleID ) {
             my $Output = $LayoutObject->CustomerHeader(
@@ -1029,7 +1028,7 @@ sub _Mask {
             Data => {
                 Valid => $Type{ValidID},
                 %Param,
-                }
+            }
         );
     }
 
